@@ -27,6 +27,10 @@ from pyramid.security import (
     Authenticated,
     Everyone,
     )
+    
+from .tools import (
+    as_timezone,
+    )
 
 
 DBSession = scoped_session(sessionmaker(extension=ZopeTransactionExtension()))
@@ -114,6 +118,16 @@ class User(UserMixin, Base):
     @classmethod
     def get_by_email(cls, email):
         return DBSession.query(cls).filter_by(email=email).first()
+
+    @classmethod
+    def get_by_name(cls, name):
+        return DBSession.query(cls).filter_by(user_name=name).first()        
+        
+    @classmethod
+    def get_by_identity(cls, identity):
+        if identity.find('@') > -1:
+            return cls.get_by_email(identity)
+        return cls.get_by_name(identity)        
             
     def get_groups(self):
         return UserGroup.get_by_user(self)
@@ -121,7 +135,54 @@ class User(UserMixin, Base):
 
 class ExternalIdentity(ExternalIdentityMixin, Base):
     pass
+    
+    
+##############
+# Base model #
+##############
+class CommonModel(object):
+    def to_dict(self): # Elixir like
+        values = {}
+        for column in self.__table__.columns:
+            values[column.name] = getattr(self, column.name)
+        return values
+        
+    def from_dict(self, values):
+        for column in self.__table__.columns:
+            if column.name in values:
+                setattr(self, column.name, values[column.name])
 
+    def as_timezone(self, fieldname):
+        date_ = getattr(self, fieldname)
+        return date_ and as_timezone(date_) or None
+
+
+class BaseModel(CommonModel):
+    id = Column(Integer, primary_key=True)
+
+    def save(self):
+        if self.id:
+            #Who knows another user edited, so use merge ()
+            DBSession.merge(self)
+        else:
+            DBSession.add(self)    
+        
+    @classmethod
+    def query(cls):
+        return DBSession.query(cls)
+
+    @classmethod
+    def query_id(cls, id):
+        return cls.query().filter_by(id=id)
+        
+    @classmethod
+    def get_by_id(cls, id):
+        return cls.query_id(id).first()                
+
+    @classmethod
+    def delete(cls, id):
+        cls.query_id(id).delete()
+    
 
 class RootFactory(object):
     def __init__(self, request):
@@ -137,57 +198,3 @@ def init_model():
     ziggurat_model_init(User, Group, UserGroup, GroupPermission, UserPermission,
                    UserResourcePermission, GroupResourcePermission, Resource,
                    ExternalIdentity, passwordmanager=None)
-
-
-##################        
-# Initialization #
-##################
-def create_anonymous():
-    email = 'anonymous@local'
-    try:
-        return DBSession.query(User).filter_by(email=email).one()
-    except NoResultFound:
-        from random import randrange    
-        user = User(email=email)
-        user.password = str(randrange(100000, 999999))
-        user.status = 1
-        user.id = 0
-        DBSession.add(user)
-        DBSession.flush()
-    return user
-    
-def create_admin():
-    email = 'admin@local'
-    try:
-        return DBSession.query(User).filter_by(email=email).one()
-    except NoResultFound:
-        user = User(email=email)
-        user.password = 'admin'
-        user.status = 1
-        DBSession.add(user)
-        DBSession.flush()
-    return user    
-
-def init_db():
-    create_anonymous()
-    user = create_admin()
-    groups = [('Admin', 'Can change'),
-              ('Staff', 'Read only'),
-             ]
-    for name, desc in groups:
-        try:
-            group = DBSession.query(Group).filter_by(group_name=name).one()
-        except NoResultFound:
-            group = Group(group_name=name, description=desc)
-            DBSession.add(group)
-            DBSession.flush()
-    # Register admin@local to Admin group
-    user_group = DBSession.query(UserGroup).filter_by(user_id=user.id,
-                                                      group_id=group.id)
-    try:
-        user_group = user_group.one()
-    except NoResultFound:
-        user_group = UserGroup(user_id=user.id, group_id=group.id)
-        DBSession.add(user_group)
-        DBSession.flush()
-    transaction.commit()
