@@ -20,12 +20,5 @@ def group_finder(email, request):
         
 def get_user(request):
     username = authenticated_userid(request)
-    if not username:
-        return
-    try:
-        return User.get_by_email(username)
-    except:
-        f = StringIO()
-        traceback.print_exc(file=f)
-        print(f.getvalue())
-        f.close()
+    if username:
+        return User.get_by_identity(username)
